@@ -1,15 +1,14 @@
-import h5 as _h5
+from . import h5 as _h5
 
-version = _h5._version_string
+version = "2.0.0"
 _exp = version.partition('-')
 version_tuple = tuple(int(x) for x in _exp[0].split('.')) + (_exp[2],)
 
-
-hdf5_version_tuple = _h5._hdf5_version_tuple
+hdf5_version_tuple = _h5.get_libversion()
 hdf5_version = "%d.%d.%d" % hdf5_version_tuple
 
-api_version_tuple = _h5._api_version_tuple
-api_version = "%d.%d" % api_version_tuple
+api_version_tuple = (1,8)
+api_version = "1.8"
 
 __doc__ = """\
 This is h5py **%s**
